🔖 [Table of Contents](README.md)

# For contributors


As contributors, there are some things you can do:

- Increase code coverage
- Report bugs
- Help others in discussion

To develop Zrb in your local computer, you need to fork Zrb repository and pull it to your local computer.

Once you do so, you can activate the environment, run Zrb test and play with playground.


```bash
source ./project.sh

# Run test
zrb test

# Start playground
zrb playground
```

If you find any bugs, or want to add new features, please open a pull request on Zrb repository.


🔖 [Table of Contents](README.md)